.. Numba documentation master file, created by
   sphinx-quickstart on Tue Dec 30 11:55:40 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Numba documentation
===================

This is the Numba documentation.  Unless you are already acquainted
with Numba, we suggest you start with the :doc:`User manual <user/index>`.


.. toctree::
   :caption: For all users
   :maxdepth: 2

   user/index.rst
   reference/index.rst


.. toctree::
   :caption: For CUDA users
   :maxdepth: 2

   cuda/index.rst
   cuda-reference/index.rst


.. toctree::
   :caption: For advanced users & developers
   :maxdepth: 2

   extending/index.rst
   developer/index.rst
   proposals/index.rst
   glossary.rst
   release-notes.rst
